cockatoo |release| Documentation
=======================================

.. figure:: images/cockatoo-logo.png

A similarity metric for macromolecular crystallization conditions.

Overview
--------

:doc:`installation`
  Instructions on how to install cockatoo.

:doc:`tutorial`
  Start here for a quick overview.

:doc:`examples/index`
  Examples of how to run cockatoo.

:doc:`api/index`
  The API documentation.

:doc:`changelog`
  Full list of changes to cockatoo

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. toctree::
   :hidden:

   installation
   tutorial
   examples/index
   api/index
   changelog


